@@ -173,11 +173,15 @@ gffpath <- "GFFRObjects"
 		#print(mi)
 		if(approx){
 		o_b_j_sub  <- list(matrix=mi,reference=NaN, positions=cn)
-                }else{
-		diplmi     <- mi
+                }else{ # create diploid matrix
+                diplmi <- as.character(mi)
+                diplmi <- strsplit(diplmi,split="")
+                diplmi <- as.numeric(unlist(diplmi))
+                diplmi <- matrix(diplmi, length(diplNAMES), dim(mi)[2]) 
+		#diplmi     <- mi
 		# modify matrix
-		diplmi     <- matrix(as.character(diplmi),nrow=dim(diplmi)[1],ncol=dim(diplmi)[2]) #apply(diplmi,2,as.character)
-		diplmi     <- apply(diplmi,2,function(x){as.numeric(sapply(strsplit(x,split=""),rbind))})
+		#diplmi     <- matrix(as.character(diplmi),nrow=dim(diplmi)[1],ncol=dim(diplmi)[2]) #apply(diplmi,2,as.character)
+		#diplmi     <- apply(diplmi,2,function(x){as.numeric(sapply(strsplit(x,split=""),rbind))})
                 rownames(diplmi) <- diplNAMES		
 		o_b_j_sub  <- list(matrix=diplmi,reference=NaN, positions=cn)
                 }
